module SSG.Djot.Render

import SSG.HTML

import SSG.Djot.Inline
import SSG.Djot.Block

import Data.String
import Data.List1

import Structures.Dependent.DList

export
renderInline : Inline -> (type : String ** Html type)
renderInline HardLineBreak =
  (_ ** Void "br" [])
renderInline SoftLineBreak =
  (_ ** Text "\n")
renderInline NonBreakingSpace =
  (_ ** Text "&nbsp;")
renderInline (Text c) =
  (_ ** Text c)

export
renderInlines : List Inline -> (types : List String ** DList _ Html types)
renderInlines xs =
  fromList . map renderInline $ xs

headingLevel : HeaderLevel -> (h : String ** IsNormal h)
headingLevel H1 = ("h1" ** IsH1)
headingLevel H2 = ("h2" ** IsH2)
headingLevel H3 = ("h3" ** IsH3)
headingLevel H4 = ("h4" ** IsH4)
headingLevel H5 = ("h5" ** IsH5)
headingLevel H6 = ("h6" ** IsH6)

export
renderBlock : Block -> (type : String ** Html type)
renderBlock (Paragraph contents) =
  let (_ ** xs) = renderInlines $ forget contents
  in (_ ** Normal "p" [] xs)
renderBlock (Heading level contents) =
  let (_ ** xs) = renderInlines $ forget contents
      (level ** _ ) = headingLevel level
  in (_ ** Normal level [] xs)

export
renderBlocks : List Block -> (types : List String ** DList _ Html types)
renderBlocks xs = fromList $ map renderBlock xs

export
renderHtml : List Block -> Html "html"
renderHtml xs =
  let (_ ** xs) = renderBlocks xs
  in Normal "html" ["lang" =$ "en"] xs
